@@ -6,10 +6,12 @@ from trytond.pool import Pool
 from .configuration import Configuration
 from .wizard import UpdateNowWizard
 from .currency import Currency
+from .cron import Cron
 
 
 def register():
     Pool.register(
+        Cron,
         Configuration,
         Currency,
         module='currency_rate_import_ecb', type_='model')
